@@ -8,30 +8,33 @@
 #'
 #' Extract draws from a Bayesian fit into a wide-format data frame with a
 #' `.chain`, `.iteration`, and `.draw` column, as well as all variables
-#' as columns. While this function can be useful for quick glances at models (especially
-#' combined with [gather_variables()] and [median_qi()]), it is
-#' generally speaking not as useful as [spread_draws()] or
-#' [gather_draws()] for most applications, and is mainly used internally (see *Details*).
+#' as columns. This function does not parse indices from variable names
+#' (e.g. for variable names like `"x[1]"`); see [spread_draws()] or
+#' [gather_draws()] for functions that parse variable indices.
 #'
-#' In practice, apart from quick looks at a model you will probably not call this directly;
-#' [spread_draws()] or [gather_draws()], which are build on top of this
-#' function, provide support for extracting variable dimensions are so are often more useful.
+#' This function can be useful for quick glances at models (especially
+#' combined with [gather_variables()] and [median_qi()]), and for models with
+#' parameters without indices in their names (like `"x[1]"`).
+#' [spread_draws()] and [gather_draws()], which *do* parse variable name indices,
+#' call this function internally if their input is not already a tidy data frame.
 #'
 #' To provide support for new models in tidybayes,
 #' you must provide an implementation of this function *or* an implementation
 #' of [coda::as.mcmc.list()] (`tidy_draws` should work on any model
 #' with an implementation of [coda::as.mcmc.list()])
 #'
-#' `tidy_draws` can be applied to a data frame that is already a tidy-format data frame
+#' `tidy_draws()` can be applied to a data frame that is already a tidy-format data frame
 #' of draws, provided it has one row per draw. In other words, it can be applied to data frames
 #' that have the same format it returns, and it will return the same data frame back, while
 #' checking to ensure the `.chain`, `.iteration`, and `.draw` columns are all
 #' integers (converting if possible) and that the `.draw` column is unique. This allows
 #' you to pass already-tidy-format data frames into other tidybayes functions, like
-#' [spread_draws()] or [gather_draws()].
+#' [spread_draws()] or [gather_draws()]. This functionality can be useful if the
+#' tidying step is expensive: you can tidy once, possibly subsetting to some
+#' particular variables of interest, then call [spread_draws()] or [gather_draws()]
+#' repeatedly to extract variables and indices from the already-tidied data frame.
 #'
-#' @param model A supported Bayesian model fit object. See [tidybayes-models()] for a list of supported
-#' models.
+#' @template param-model
 #' @param ... Further arguments passed to other methods (mostly unused).
 #' @return A data frame (actually, a [tibble][tibble::tibble]) with a `.chain` column,
 #' `.iteration` column, `.draw` column, and one column for every variable in `model`.
@@ -48,7 +51,6 @@
 #' line %>%
 #'   tidy_draws()
 #'
-#' @importFrom purrr map_dfr
 #' @importFrom dplyr bind_cols
 #' @importFrom tibble as_tibble tibble
 #' @importFrom coda as.mcmc.list as.mcmc
@@ -57,8 +59,31 @@ tidy_draws = function(model, ...) UseMethod("tidy_draws")
 
 #' @rdname tidy_draws
 #' @export
+#' @importFrom posterior as_draws_df as_draws
+#' @importFrom coda as.mcmc.list
 tidy_draws.default = function(model, ...) {
-  draws = tidy_draws(as.mcmc.list(model))
+  signature = class(model)
+  if (has_method("as_draws_df", signature)) {
+    draws = as_tibble(as_draws_df(model))
+  } else if (has_method("as_draws", signature)) {
+    draws = as_tibble(as_draws_df(as_draws(model)))
+  } else if (has_method("as.mcmc.list", signature)) {
+    draws = tidy_draws(as.mcmc.list(model))
+  } else {
+    stop(
+      "Don't know how to convert an object of class ", deparse0(signature), "\n",
+      "into a tidy data frame of draws. See help(\"tidybayes-models\") for a list\n",
+      "of models supported by tidy_draws()."
+    )
+  }
+  attr(draws, "tidybayes_constructors") = attr(model, "tidybayes_constructors")
+  draws
+}
+
+#' @rdname tidy_draws
+#' @export
+tidy_draws.draws = function(model, ...) {
+  draws = as_tibble(as_draws_df(model))
   attr(draws, "tidybayes_constructors") = attr(model, "tidybayes_constructors")
   draws
 }
@@ -141,15 +166,8 @@ tidy_draws.mcmc.list = function(model, ...) {
 #' @rdname tidy_draws
 #' @export
 tidy_draws.stanfit = function(model, ...) {
-  if (!requireNamespace("rstan", quietly = TRUE)) {
-    stop("The `rstan` package is needed for `tidy_draws` to support `stanfit` objects.", call. = FALSE) # nocov
-  }
-
-  parameter_draws = tidy_draws(rstan::As.mcmc.list(model), ...)
-
-  diagnostics_draws = map_dfr(rstan::get_sampler_params(model, inc_warmup = FALSE), as.data.frame)
-
-  draws = bind_cols(parameter_draws, diagnostics_draws)
+  draws = tidy_draws(rstan::As.mcmc.list(model), ...)
+  draws = add_rstan_sampler_param_draws(draws, model)
 
   attr(draws, "tidybayes_constructors") = attr(model, "tidybayes_constructors")
   draws
@@ -158,30 +176,42 @@ tidy_draws.stanfit = function(model, ...) {
 #' @rdname tidy_draws
 #' @export
 tidy_draws.stanreg = function(model, ...) {
-  if (!requireNamespace("rstanarm", quietly = TRUE)) {
-    stop("The `rstanarm` package is needed for `tidy_draws` to support `stanreg` objects.", call. = FALSE) # nocov
-  }
   #stanreg objects have more info provided for variable names than the underlying stanfit,
   #so we dont' just do tidy_draws(model$stanfit)
   sample_matrix = as.array(model) #[iteration, chain, variable]
   n_chain = dim(sample_matrix)[[2]]
   mcmc_list = as.mcmc.list(lapply(seq_len(n_chain), function(chain) as.mcmc(sample_matrix[, chain, ]))) # nolint
-  parameter_draws = tidy_draws(mcmc_list, ...)
-
-  diagnostics_draws = map_dfr(rstan::get_sampler_params(model$stanfit, inc_warmup = FALSE), as.data.frame)
-
-  draws = bind_cols(parameter_draws, diagnostics_draws)
+  draws = tidy_draws(mcmc_list, ...)
+  draws = add_rstan_sampler_param_draws(draws, model$stanfit)
 
   attr(draws, "tidybayes_constructors") = attr(model, "tidybayes_constructors")
   draws
 }
 
+#' Helper to add sampler params from an rstan model to a tidy data frame of draws
+#' so long as sampler params are actually present
+#' @noRd
+add_rstan_sampler_param_draws = function(draws, model, inc_warmup = FALSE) {
+  # TODO: this is ugly but I can't find a better way to determine if a model
+  # type supports sampler params or not
+  sampler_params = tryCatch({
+    rstan::get_sampler_params(model, inc_warmup = inc_warmup)
+  }, error = function(e) {
+    list()
+  })
+
+  sampler_param_draws = map_dfr_(sampler_params, as.data.frame, optional = TRUE)
+
+  if (length(sampler_param_draws) > 0) {
+    bind_cols(draws, sampler_param_draws)
+  } else {
+    draws
+  }
+}
+
 #' @rdname tidy_draws
 #' @export
 tidy_draws.runjags = function(model, ...) {
-  if (!requireNamespace("runjags", quietly = TRUE)) {
-    stop("The `runjags` package is needed for `tidy_draws` to support `runjags` objects.", call. = FALSE) # nocov
-  }
   draws = tidy_draws(as.mcmc.list(model), ...)
   attr(draws, "tidybayes_constructors") = attr(model, "tidybayes_constructors")
   draws
@@ -190,9 +220,6 @@ tidy_draws.runjags = function(model, ...) {
 #' @rdname tidy_draws
 #' @export
 tidy_draws.jagsUI = function(model, ...) {
-  if (!requireNamespace("jagsUI", quietly = TRUE)) {
-    stop("The `jagsUI` package is needed for `tidy_draws` to support `jagsUI` objects.", call. = FALSE) # nocov
-  }
   draws = tidy_draws(as.mcmc.list(model$samples), ...)
   attr(draws, "tidybayes_constructors") = attr(model, "tidybayes_constructors")
   draws
@@ -201,15 +228,28 @@ tidy_draws.jagsUI = function(model, ...) {
 #' @rdname tidy_draws
 #' @export
 tidy_draws.brmsfit = function(model, ...) {
-  if (!requireNamespace("brms", quietly = TRUE)) {
-    stop("The `brms` package is needed for `tidy_draws` to support `brmsfit` objects.", call. = FALSE) # nocov
-  }
+  draws = tidy_draws(brms::as.mcmc(model), ...)
+  draws = add_rstan_sampler_param_draws(draws, model$fit)
 
-  parameter_draws = tidy_draws(brms::as.mcmc(model), ...)
+  attr(draws, "tidybayes_constructors") = attr(model, "tidybayes_constructors")
+  draws
+}
 
-  diagnostics_draws = map_dfr(rstan::get_sampler_params(model$fit, inc_warmup = FALSE), as.data.frame)
+#' @rdname tidy_draws
+#' @importFrom posterior as_draws_df
+#' @export
+tidy_draws.CmdStanFit = function(model, ...) {
+  draws = as_tibble(as_draws_df(model$draws()))
 
-  draws = bind_cols(parameter_draws, diagnostics_draws)
+  attr(draws, "tidybayes_constructors") = attr(model, "tidybayes_constructors")
+  draws
+}
+
+#' @rdname tidy_draws
+#' @importFrom posterior bind_draws as_draws_df
+#' @export
+tidy_draws.CmdStanMCMC = function(model, ...) {
+  draws = as_tibble(as_draws_df(bind_draws(model$draws(), model$sampler_diagnostics())))
 
   attr(draws, "tidybayes_constructors") = attr(model, "tidybayes_constructors")
   draws
@@ -227,7 +267,6 @@ tidy_draws.matrix = function(model, ...) {
 
 #' @rdname tidy_draws
 #' @importFrom dplyr inner_join
-#' @importFrom purrr discard
 #' @export
 tidy_draws.MCMCglmm = function(model, ...) {
   # draws from MME solutions, including fixed effects
@@ -236,8 +275,8 @@ tidy_draws.MCMCglmm = function(model, ...) {
   # draws from (co)variance matrices, ordinal cutpoints, and latent variables
   other_draws =
     model[c("VCV", "CP", "Liab")] %>%
-    discard(is.null) %>%
-    map2(names(.), function(draws, param_type) {
+    discard_(is.null) %>%
+    map2_(names(.), function(draws, param_type) {
       dimnames(draws)[[2]] %<>% paste0(param_type, "_", .)
       tidy_draws(draws, ...)
     })
@@ -245,7 +284,7 @@ tidy_draws.MCMCglmm = function(model, ...) {
   draws = sol_draws %>%
     list() %>%
     c(other_draws) %>%
-    reduce(inner_join, by = c(".chain", ".iteration", ".draw"))
+    reduce_(inner_join, by = c(".chain", ".iteration", ".draw"))
 
   attr(draws, "tidybayes_constructors") = attr(model, "tidybayes_constructors")
   draws
