@@ -5,11 +5,10 @@
 
 library(tibble)
 library(dplyr)
-library(purrr)
 library(magrittr)
 library(coda)
 
-context("tidy_draws")
+
 
 
 
@@ -18,7 +17,7 @@ test_that("tidy_draws works with brms", {
   skip_if_not_installed("brms")
 
   # we use a model with random effects here because they include parameters with multiple dimensions
-  m_ranef = readRDS("../models/models.brms.m_ranef.rds")
+  m_ranef = readRDS(test_path("../models/models.brms.m_ranef.rds"))
 
   draws_tidy =
     brms::posterior_samples(m_ranef, add_chain = TRUE) %>%
@@ -30,7 +29,7 @@ test_that("tidy_draws works with brms", {
     ) %>%
     as_tibble() %>%
     select(.chain, .iteration, .draw, everything()) %>%
-    bind_cols(map_dfr(rstan::get_sampler_params(m_ranef$fit, inc_warmup = FALSE), as_tibble))
+    bind_cols(bind_rows(lapply(rstan::get_sampler_params(m_ranef$fit, inc_warmup = FALSE), as_tibble)))
 
   expect_equal(tidy_draws(m_ranef), draws_tidy)
 })
@@ -41,7 +40,7 @@ test_that("tidy_draws works with rstanarm", {
   skip_if_not_installed("rstanarm")
 
   # we use a model with random effects here because they include parameters with multiple dimensions
-  m_ranef = readRDS("../models/models.rstanarm.m_ranef.rds")
+  m_ranef = readRDS(test_path("../models/models.rstanarm.m_ranef.rds"))
 
   chain_1 = as_tibble(as.array(m_ranef)[,1,]) %>%
     add_column(.chain = 1L, .iteration = 1L:nrow(.), .draw = 1L:nrow(.), .before = 1)
@@ -49,19 +48,18 @@ test_that("tidy_draws works with rstanarm", {
     add_column(.chain = 2L, .iteration = 1L:nrow(.), .draw = (nrow(.) + 1L):(2L * nrow(.)), .before = 1)
   draws_tidy =
     bind_rows(chain_1, chain_2) %>%
-    bind_cols(map_dfr(rstan::get_sampler_params(m_ranef$stanfit, inc_warmup = FALSE), as_tibble))
+    bind_cols(bind_rows(lapply(rstan::get_sampler_params(m_ranef$stanfit, inc_warmup = FALSE), as_tibble)))
 
   expect_equal(tidy_draws(m_ranef), draws_tidy)
 })
 
 
-
 # rstan -------------------------------------------------------------------
 test_that("tidy_draws works with rstan", {
   skip_if_not_installed("rstan")
 
   # we use a model with random effects here because they include parameters with multiple dimensions
-  m_ABC = readRDS("../models/models.rstan.m_ABC.rds")
+  m_ABC = readRDS(test_path("../models/models.rstan.m_ABC.rds"))
 
   chain_1 = as_tibble(as.array(m_ABC)[,1,]) %>%
     add_column(.chain = 1L, .iteration = 1L:nrow(.), .draw = 1L:nrow(.), .before = 1)
@@ -69,11 +67,23 @@ test_that("tidy_draws works with rstan", {
     add_column(.chain = 2L, .iteration = 1L:nrow(.), .draw = (nrow(.) + 1L):(2L * nrow(.)), .before = 1)
   draws_tidy =
     bind_rows(chain_1, chain_2)  %>%
-    bind_cols(map_dfr(rstan::get_sampler_params(m_ABC, inc_warmup = FALSE), as_tibble))
+    bind_cols(bind_rows(lapply(rstan::get_sampler_params(m_ABC, inc_warmup = FALSE), as_tibble)))
 
   expect_equal(tidy_draws(m_ABC), draws_tidy)
 })
 
+test_that("tidy_draws works with rstan without sampler params", {
+  skip_if_not_installed("rstan")
+
+  m_gqs = readRDS(test_path("../models/models.rstan.m_gqs.rds"))
+
+  draws_tidy =
+    tibble(y_rep = as.vector(as.array(m_gqs))) %>%
+    add_column(.chain = 1L, .iteration = 1L:nrow(.), .draw = 1L:nrow(.), .before = 1)
+
+  expect_equal(tidy_draws(m_gqs), draws_tidy)
+})
+
 
 # jags --------------------------------------------------------------------
 test_that("tidy_draws works with runjags", {
@@ -210,3 +220,12 @@ test_that("tidy_draws fails on existing data frames with incorrect column types"
 
   expect_error(tidy_draws(tidy_rc), "The `\\.draw` column in the input data frame has more than one row per draw")
 })
+
+# posterior::draws --------------------------------------------------------
+
+test_that("tidy_draws works on a draws object", {
+  d = posterior::example_draws()
+
+  expect_equal(tidy_draws(d), as_tibble(posterior::as_draws_df(d)))
+})
+
